@@ -12,11 +12,30 @@ import json
 import requests
 
 
+REQUIREFOLIADOCSERVE = '0.6'
+
+def checkversion(version):
+    """Checks foliadocserve version, returns 1 if the document is newer than the library, -1 if it is older, 0 if it is equal"""
+    try:
+        for refversion, responseversion in zip([int(x) for x in REQUIREFOLIADOCSERVE.split('.')], [int(x) for x in version.split('.')]):
+            if responseversion > refversion:
+                return 1 #response is newer than library
+            elif responseversion < refversion:
+                return -1 #response is older than library
+        return 0 #versions are equal
+    except ValueError:
+        raise ValueError("Unable to parse version, invalid syntax")
+
+
 def getsid(request):
-    if 'X-sessionid' in request.META:
-        return request.session.session_key + '_' + request.GET['sid']
+    if 'HTTP_X_SESSIONID' in request.META:
+        return request.META['HTTP_X_SESSIONID'] #accesses X-Sessionid header
+    elif 'sid' in request.POST:
+        return request.POST['sid']
+    elif 'sid' in request.GET:
+        return request.GET['sid']
     else:
-        return request.session.session_key + '_NOSID'
+        return 'NOSID'
 
 def setsid(request, sid):
     request.add_header('X-sessionid', sid)
@@ -45,7 +64,12 @@ def query(request, query, parsejson=True, **extradata):
     if contents and contents[0] in ('{','['):
         #assume this is json
         if parsejson:
-            return json.loads(contents)
+            parsed = json.loads(contents)
+            if 'version' not in parsed:
+                raise Exception("No version information supplied by foliadocserve, it is likely too old, please upgrade")
+            elif checkversion(parsed['version']) == -1:
+                raise Exception("Foliadocserve version is too old, got " + parsed['version'] + ", expected at " + REQUIREFOLIADOCSERVE + ", please upgrade")
+            return parsed
         else:
             return contents
     elif contents:
@@ -58,6 +82,7 @@ def query(request, query, parsejson=True, **extradata):
 
 
 
+
 def get( request, url, parsejson=True):
     docservereq = Request("http://" + settings.FOLIADOCSERVE_HOST + ":" + str(settings.FOLIADOCSERVE_PORT) + "/" + url) #or opener.open()
     setsid(docservereq, getsid(request))
@@ -81,6 +106,27 @@ def get( request, url, parsejson=True):
         else:
             return ""
 
+def filemanagement(request, filemanmode, namespace, doc, **data):
+    if sys.version < '3':
+        #encode for python 2
+        for key, value in data.items():
+            if isinstance(value,unicode): #pylint: disable=undefined-variable
+                data[key] = value.encode('utf-8')
+
+    docservereq = Request("http://" + settings.FOLIADOCSERVE_HOST + ":" + str(settings.FOLIADOCSERVE_PORT) + "/" + filemanmode + "/" + namespace + "/" + doc)
+    setsid(docservereq, getsid(request))
+    f = urlopen(docservereq,urlencode(data).encode('utf-8')) #or opener.open()
+    if sys.version < '3':
+        contents = unicode(f.read(),'utf-8') #pylint: disable=undefined-variable
+    else:
+        contents = str(f.read(),'utf-8')
+    f.close()
+    if contents and contents[0] in ('{','['):
+        return json.loads(contents)
+    else:
+        return None
+
+
 def postjson( request, url, data):
     if isinstance(data, dict) or isinstance(data,list) or isinstance(data, tuple):
         data = json.dumps(data)
