@@ -1,163 +1,107 @@
 // jshint evil:true
-var annotationtypenames = {
-    'pos': 'Part-of-Speech',
-    'lemma': 'Lemma',
-    't': 'Text',
-    'ph': 'Phonetic Content',
-    'w': 'Word/Token',
-    's': 'Sentence',
-    'p': 'Paragraph',
-    'div': 'Division',
-    'entity': 'Entity',
-    'su': 'Syntax',
-    'chunk': 'Chunk',
-    'sense': 'Semantic Sense',
-    'semrole': 'Semantic Role',
-    'correction': 'Correction',
-    'errordetection': 'Error detection',
-    'dependency': 'Dependency',
-    'coreferencechain': 'Coreference',
-    'note': 'Note',
-    'entry': 'Entry',
-    'def': 'Definition',
-    'term': 'Term',
-    'gap': 'Gap',
-    'event': 'Event',
-    'alignment': 'Alignments',
-    'morpheme': 'Morpheme',
-    'phoneme': 'Phoneme',
-    'lang': 'Language',
-    'ex': 'Example',
-    'part': 'Part',
-    'timesegment': 'Time Segment',
-    'cell': 'Table cell',
-    'row': 'Table row',
-    'metric': 'Metric',
-    'str': 'String'
-};
-var annotationtypespan = {
-    'pos': false,
-    'lemma': false,
-    't': false,
-    'ph': false,
-    'w': false,
-    's': false,
-    'p': false,
-    'div': false,
-    'entity': true,
-    'su': true,
-    'chunk': true,
-    'sense': true,
-    'semrole': true,
-    'correction': true,
-    'errordetection': false,
-    'dependency': true,
-    'coreferencechain': true,
-};
-var annotationtypestructure = ['p','w','s','div','event','utt'];
-var spanroles = {
-    'coreferencechain': ['coreferencelink'],
-    'dependency': ['hd','dep'],
-};
 
-
-var sid = ((Math.random() * 1e9) | 0); //session id
+//A random session ID
+var sid = ((Math.random() * 1e9) | 0);
 
 var havecontent = false; //we start assuming we have no content
 var closewait = true; //close the wait mask when we are done loading
-var textclass = "current";
+var textclass = "current"; //the default text class: "current"
 
 var perspective = 'document'; //initial perspective (will be overriden from config in init anyway)
 var perspective_ids = null;
 var perspective_start = null;
 var perspective_end = null;
 
+var selector = ""; //structural element to select when clicking/hovering: empty selector selects deepest element (default)
+
+var structure = {}; //structural items
 var annotations = {}; //annotations per structure item
+var latestannotations = {}; //latest annotations cache (annotationid -> true map), will be populated again by loadannotations()
+var lateststructure = {}; //latest structure cache (structureid -> true map), will be populated again by loadstructure()
 var declarations = {};
-var corrections = {};
 var docid = null;
 var initialannotationlist = [];
 var initialdeclarationlist = [];
 var mouseX = 0;
 var mouseY = 0;
 
-function getannotationtypename(t) {
-    if (annotationtypenames[t]) {
-        return annotationtypenames[t];
-    }
-    return t;
-}
+var poll = true;
+
+//************************************************************************************************************************************************************************
 
 function function_exists(functionName) {
+    //Test if a function exists
     if(eval("typeof(" + functionName + ") == typeof(Function)")) {
         return true;
     }
 }
 
 
-function isstructure(annotationtype) {
-    return (annotationtypestructure.indexOf(annotationtype) !== -1);
-}
 
 function hash(s){
+  //Generic hash function
   if (s) {
     return s.split("").reduce(function(a,b){a=((a<<5)-a)+b.charCodeAt(0);return a&a},0);  //jshint ignore:line
   }
   return 0;
 }
 
-function getannotationid(annotation) {
-    if (annotation.self) {
-        return "self";
-    }
-    if (annotation.id)  {
-        return annotation.id;
-    }
-    if (annotation.type === 't') {
-        return annotation.type + '/' + annotation.set + ':' + annotation.class;
-    }
-    if (annotation.set) {
-        return annotation.type + '/' + annotation.set;
-    }
-    if (annotation.type) {
-        return annotation.type;
-    }
-    alert("Unable to get ID for " + annotation);
-}
-
 function onfoliaclick() {
+    //Called when an element (often a word) is clicked, delegates to *_onclick methods of the enabled mode
     if (function_exists(mode + '_onclick')) {
-        var f = eval(mode + '_onclick');
-        f(this);
+        if ((selector === "") || (selector == structure[this.id].type)) {
+            var f = eval(mode + '_onclick');
+            f(this);
+            return false;
+        }
     }
-    return false;
 }
 function onfoliadblclick() {
+    //Called when an element (often a word) is double clicked, delegates to *_ondblclick methods of the enabled mode
     if (function_exists(mode + '_ondblclick')) {
-        var f = eval(mode + '_ondblclick');
-        f(this);
+        if ((selector === "") || (selector == structure[this.id].type)) {
+            var f = eval(mode + '_ondblclick');
+            f(this);
+            return false;
+        }
     }
-    return false;
 }
 function onfoliamouseenter() {
+    //Called when an element (often a word) is entered with the cursor, delegates to *_mouseenter methods of the enabled mode
     if (function_exists(mode + '_onmouseenter')) {
-        var f = eval(mode + '_onmouseenter');
-        f(this);
+        if ((selector === "") || (selector == structure[this.id].type)) {
+            var f = eval(mode + '_onmouseenter');
+            f(this);
+            return false;
+        }
     }
-    return false;
 }
 function onfoliamouseleave() {
+    //Called when an element (often a word) is exited with the cursor, delegates to *_mouseleave methods of the enabled mode
     if (function_exists(mode + '_onmouseleave')) {
-        var f = eval(mode + '_onmouseleave');
-        f(this);
+        if ((selector === "") || (selector == structure[this.id].type)) {
+            var f = eval(mode + '_onmouseleave');
+            f(this);
+            return false;
+        }
     }
-    return false;
 }
 
-function loadtext(annotationlist) {
-    //reload text into the structure
-    annotationlist.forEach(function(annotation){
-        if ((annotation.type == "t") && (annotation.text) && (annotation.class == "current")) {
+
+function loadstructure(structureresponse) {
+    //update structure data
+    Object.keys(structureresponse).forEach(function(structureid){
+        structure[structureid] = structureresponse[structureid];
+        lateststructure[structureid] = true;
+    });
+    //old (deleted) structure may linger in memory but is no longer
+    //referenced by other structure or other updated annotations
+}
+
+function loadtext(annotationresponse) {
+    //reload text from the annotation data response back into the DOM structure, called by update()
+    forlatestannotations(function(annotation){
+        if ((annotation.type == "t") && (annotation.text) && (annotation.class == "current") && (annotation.auth)) {
             if (annotation.targets) {
                 annotation.targets.forEach(function(target){
                     if (target) { $('#' + valid(target) + " span.lbl").html(annotation.text); }
@@ -171,82 +115,133 @@ function loadtext(annotationlist) {
     }*/
 }
 
-function loadannotations(annotationlist) {
-    //load annotations in memory
-    var annotationexists = {};
-
-    annotationlist.forEach(function(annotation){
-        annotation.targets.forEach(function(target){
-            if (!(annotations[target])) annotations[target] = {};
-            if (!(annotationexists[target])) annotationexists[target] = {};
-            var annotationid = getannotationid(annotation);
-            annotations[target][annotationid] = annotation;
-            annotations[target][annotationid].annotationid = annotationid;
-            annotationexists[target][annotationid] = true;
-        });
-        if ((annotation.type == "correction") && (annotation.id)) {
-            corrections[annotation.id] = annotation;
-            if ((annotation.suggestions.length > 0) && (annotation.new.length === 0)) {
-                //find the annotation the suggestions apply to and act as if
-                //that is part of the correction
-                target = annotation.targets[0];
-                Object.keys(annotations[target]).forEach(function(annotationid){
-                    if (annotationid != "self") {
-                        if ((annotations[target][annotationid].type == annotation.suggestions[0].type) && (annotations[target][annotationid].set == annotation.suggestions[0].set)) {
-                            if (!annotations[target][annotationid].incorrection) {
-                                annotations[target][annotationid].incorrection = [annotation.id];
-                            } else {
-                                annotations[target][annotationid].incorrection.push(annotation.id);
-                            }
-                        }
-                    }
-                });
-            }
-        }
+function loadannotations(annotationresponse) {
+    Object.keys(annotationresponse).forEach(function(annotationid){
+        annotations[annotationid] = annotationresponse[annotationid];
+        latestannotations[annotationid] = true;
     });
-
-    //find old annotations that are no longer in the response, delete them
-    Object.keys(annotationexists).forEach(function(target){
-        if (annotations[target]) {
-            Object.keys(annotations[target]).forEach(function(annotationid){
-                if (!annotationexists[target][annotationid]) delete annotations[target][annotationid];
-            });
-        }
-    });
-
-    /*
-    if (function_exists(mode + '_onloadannotations')) {
-        f = eval(mode + '_onloadannotations');
-        f(annotationlist);
-    }
-    */
+    //old (deleted) annotations may linger in memory but are no longer
+    //referenced by structure or other updated annotations
 }
 
 
 function loaddeclarations(declarationlist) {
+    //parse the metadata response and populate the declarations structure in memory, declarationlist is supplied through the server-side template on page load
     declarationlist.forEach(function(declaration){
         if (!declarations[declaration.annotationtype])  declarations[declaration.annotationtype] =  {};
         declarations[declaration.annotationtype][declaration.set] = { 'settype': 'open', 'classes': [] }; //this will hold proper set definitions later on
     });
 }
 
-function rendertextclass() {
-    Object.keys(annotations).forEach(function(target){
-        Object.keys(annotations[target]).forEach(function(annotationid){
-            var annotation = annotations[target][annotationid];
-            if ((annotation.type == "t") && (annotation.class == textclass)) {
-                lbl = $('#' + valid(target) + " span.lbl");
-                if ((lbl.length == 1) && ($('#'  + valid(target)).hasClass('deepest'))) {
-                    if (annotation.htmltext) {
-                        lbl.html(annotation.htmltext);
-                    } else {
-                        lbl.html(annotation.text);
-                    }
-                }
+function forstructure(callback) {
+    Object.keys(structure).forEach(function(structure_id){
+        callback(structure[structure_id]);
+    });
+}
+
+function forlateststructure(callback) {
+    Object.keys(lateststructure).forEach(function(structure_id){
+        callback(structure[structure_id]);
+    });
+}
+
+function forannotations(structure_id, callback) {
+    /*  Calls a function for all annotations pertaining to a specific
+     *  structural element, includes span annotations as well */
+    if ((structure[structure_id]) && (structure[structure_id].annotations)) {
+        structure[structure_id].annotations.forEach(function(annotation_id){
+            if (annotations[annotation_id]) {
+                callback(annotations[annotation_id]);
             }
         });
+    }
+}
+
+function forsubstructure(structure_id, callback) {
+    /*  Calls a function for all structural elements pertaining to a specific
+     *  structural element */
+    if ((structure[structure_id]) && (structure[structure_id].annotations)) {
+        structure[structure_id].structure.forEach(function(sub_id){
+            if (structure[sub_id]) {
+                callback(structure[sub_id]);
+            }
+        });
+    }
+}
+
+
+function forlatestannotations(structure_id, callback) {
+    /*  Calls a function for all annotations pertaining to a specific
+     *  structural element, includes span annotations as well. Only includes
+     *  annotations that were returned in the latest response from server */
+    if ((structure[structure_id]) && (structure[structure_id].annotations)) {
+        structure[structure_id].annotations.forEach(function(annotation_id){
+            if (latestannotations[annotation_id]) {
+                callback(annotations[annotation_id]);
+            }
+        });
+    }
+}
+
+function forallannotations(callback) {
+    /*  Calls a function for all structure element and all annotations pertaining to the
+     *  structural element, includes span annotations as well. */
+    Object.keys(structure).forEach(function(structure_id){
+        if (structure[structure_id].annotations) {
+            structure[structure_id].annotations.forEach(function(annotation_id){
+                if (annotations[annotation_id]) {
+                    callback(structure[structure_id],annotations[annotation_id]);
+                } else {
+                    console.debug("Annotation " + annotation_id + " for structure " + structure_id + " is not defined");
+                }
+            });
+        }
+    });
+}
+
+function forspanannotations(structure_id, callback) {
+    /* Calls a function for all span annotations layered in a structural element, NOT span
+     * annotation applying over a structural element! */
+    if ((structure[structure_id]) && (structure[structure_id].annotations)) {
+        structure[structure_id].spanannotations.forEach(function(annotation_id){
+            if (annotations[annotation_id]) {
+                callback(annotations[annotation_id]);
+            }
+        });
+    }
+}
+
+function foralllatestannotations(callback) {
+    /*  Calls a function for all structure element and all annotations pertaining to the
+     *  structural element, includes span annotations as well. Only includes
+     *  annotations that were returned in the latest response from server */
+    Object.keys(lateststructure).forEach(function(structure_id){
+        if (structure[structure_id].annotations) {
+            structure[structure_id].annotations.forEach(function(annotation_id){
+                if (latestannotations[annotation_id]) {
+                    callback(structure[structure_id],annotations[annotation_id]);
+                }
+            });
+        }
+    });
+}
+
+function rendertextclass() {
+    //Renders the right text label based on the text class (current by default)
+    forallannotations(function(structureelement, annotation){
+        if ((annotation.type == "t") && (annotation.class == textclass)) {
+            lbl = $('#' + valid(structureelement.id) + " span.lbl");
+            if ((lbl.length == 1) && ($('#'  + valid(structureelement.id)).hasClass('deepest'))) {
+                if (annotation.htmltext) {
+                    lbl.html(annotation.htmltext);
+                } else {
+                    lbl.html(annotation.text);
+                }
+            }
+        }
     });
     $('div.deepest>span.lbl').show();
+    //Delegate to mode's callback function
     if (function_exists(mode + '_onrendertextclass')) {
         f = eval(mode + '_onrendertextclass');
         f();
@@ -254,6 +249,7 @@ function rendertextclass() {
 }
 
 function setupcorrection(correction) {
+    //TODO: refactor
     if (!((correction.original) || (correction.new) || (correction.current) || (correction.suggestions))) {
         //process
         correction.children.forEach(function(correctionchild){
@@ -276,15 +272,18 @@ function setupcorrection(correction) {
 }
 
 function registerhandlers() {
+    //Registers all event handlers on elements (mostly words)
     $('.F').off(); //prevent duplicates
     $('.F').click(onfoliaclick).dblclick(onfoliadblclick).mouseenter(onfoliamouseenter).mouseleave(onfoliamouseleave);
 }
 
 function valid(id){
+    //Validate a HTML DOM element ID  for use in javascript (dots need to be escaped)
     return id.replace(/\./g,'\\.');
 }
 
 function shorten(s) {
+    //Shorten set URLs for presentation
     if (s.length > 30) {
         if (s.substr(s.length -13) == ".foliaset.xml") {
             s = s.substr(0,s.length-13) + '..';
@@ -299,8 +298,13 @@ function shorten(s) {
     return s;
 }
 
-function update(data) {
-    //partial update
+function update(data, extracallback) {
+    //Process data response from the server, does a partial update, called through loadcontent() on initialisation
+    //
+
+    lateststructure = {}; //reset latest structure cache (structureid -> true map), will be populated again by loadstructure()
+    latestannotations = {}; //reset latest annotations cache (annotationid -> true map), will be populated again by loadannotations()
+
     if (data.error) {
         alert(data.error);
     }
@@ -317,7 +321,7 @@ function update(data) {
                     //update the existing elements
                     selector[0].outerHTML = returnitem.html;
                 } else if (!havecontent) {
-                    //structure does not exist yet and we we don't have content
+                    //structure does not exist yet and we don't have content
                     //yet, add to main document
                     $('#document').append(returnitem.html);
                 }
@@ -326,9 +330,12 @@ function update(data) {
                 //$('#replacing').after(data.html);
                 //$('#replacing').remove();
             }
+            if (returnitem.structure) {
+                loadstructure(returnitem.structure);
+            }
             if (returnitem.annotations) {
-                loadtext(returnitem.annotations);
                 loadannotations(returnitem.annotations);
+                loadtext(returnitem.annotations);
             }
             if (returnitem.elementid) {
                 //reregister handlers
@@ -337,29 +344,36 @@ function update(data) {
         });
         if (reregisterhandlers) registerhandlers();
         havecontent = true;
+        //Call mode-specific callback function for further processing
         if (function_exists(mode + '_onupdate')) {
             f = eval(mode + '_onupdate');
             f();
         }
+        if (extracallback) {
+            extracallback();
+        }
     }
     if (data.aborted) {
+        //If not all data could be loaded, show a note to that effect
         $('#aborted').show();
     }
 }
 
 
-function loadcontent(perspective, ids, start, end) {
-    //get query depending on the perspective
-    //  triggered on first page load and on change of perspective
+function loadcontent(perspective, ids, start, end, extracallback) {
+    //Formulates and submits an FQL query to the backend to retrieve the
+    //content, depending on the perspective
+    //  Triggered on first page load and on change of perspective/page
     //
     $('#wait .msg').html("Obtaining document data...");
     $('#wait').show();
     $('#aborted').hide();
 
     havecontent = false; //global variable to indicate we have no content (anymore)
-    annotations = {};
+    annotations = {}; //clear all annotations in memory
     $('#document').html(""); //clear document
 
+    //Formulate FQL query
     var query = "USE " + namespace + "/" + docid + " SELECT FOR";
     if (perspective == "document") {
         query += " ALL";
@@ -379,10 +393,18 @@ function loadcontent(perspective, ids, start, end) {
     }
     query += " FORMAT flat";
 
+    var url;
+    if (namespace == "pub") {
+        url = "/pub/" + configuration_id + "/"+ docid + "/query/";
+    } else {
+        url = "/" + namespace + "/"+ docid + "/query/";
+    }
 
+
+    //Submit to backend
     $.ajax({
         type: 'POST',
-        url: "/" + namespace + "/"+ docid + "/query/",
+        url: url,
         contentType: "application/json",
         //processData: false,
         headers: {'X-sessionid': sid },
@@ -393,12 +415,16 @@ function loadcontent(perspective, ids, start, end) {
                 alert("Received error from document server: " + data.error);
             } else {
                 settextclassselector(data);
-                update(data);
+                update(data, extracallback); //main function to  update all elements according to the data response
+
+                //Delegate to mode-specific callbacks
                 if (function_exists(mode + '_contentloaded')) {
                     f = eval(mode + '_contentloaded');
                     f(data);
                 }
                 if (rtl) {
+                    //Trigger right-to-left presentation for languages such as Arabic, Hebrew, Farsi,
+                    //rtl is set based on FoLiA metadata
                     $('#document').css({'direction':'rtl'} );
                 }
                 $('#wait').hide();
@@ -413,6 +439,7 @@ function loadcontent(perspective, ids, start, end) {
 }
 
 function settextclassselector(data) {
+    //Populate the text class selector and render text classes
     $('#textclassselector').hide();
     if (data.textclasses) {
         if (data.textclasses.length > 1) {
@@ -458,6 +485,7 @@ $(document).mousemove( function(e) {
 });
 
 function rendertoc(tocitem, depth) {
+    //Render Table of Contents in perspectivemenu (called by loadperspectivemenu())
     var opts = "<option value=\"div:" + tocitem.id + "\"";
     if ((perspective_ids) && (perspective_ids.indexOf(tocitem.id) != -1)) {
         opts += " selected=\"selected\">";
@@ -474,6 +502,7 @@ function rendertoc(tocitem, depth) {
 }
 
 function loadperspectivemenu() {
+    //Create and populate the perspective menu and pager
     var s = "<span class=\"title\">Perspective</span>";
     s += "<select id=\"perspectivemenu\">";
     var opts = "";
@@ -494,7 +523,7 @@ function loadperspectivemenu() {
             } else {
                 opts += ">";
             }
-            opts += annotationtypenames[perspectives[i]] + "</option>";
+            opts += folia_label(perspectives[i]) + "</option>";
         }
     }
     if (perspectives.indexOf('toc') != -1) {
@@ -536,7 +565,46 @@ function loadperspectivemenu() {
     });
 }
 
+function selectorchange(){
+    selector = $('#selectormenu').val();
+}
+
+function loadselectormenu() {
+    var s = "<span class=\"title\">Selector</span>";
+    s += "<select id=\"selectormenu\">";
+    if (selector === "") {
+        s += "<option value=\"\" selected=\"selected\">Automatic (deepest)</option>";
+    } else {
+        s += "<option value=\"\">Automatic (deepest)</option>";
+    }
+    folia_structurelist().forEach(function(structuretype){
+        var label = structuretype;
+        if (folia_label(structuretype)) {
+            label = folia_label(structuretype);
+        }
+        if (selector == structuretype) {
+            s += "<option value=\"" + structuretype + "\" selected=\"selected\">"  + label + "</option>";
+        } else {
+            s += "<option value=\"" + structuretype + "\">"  + label + "</option>";
+        }
+    });
+    s += "</select>";
+    $('#selector').html(s);
+    $('#selectormenu').off();
+    $('#selectormenu').change(selectorchange);
+}
+
+function onpagechange(){
+    //callback function called after on page change has been complete
+    if (function_exists(mode + '_onpagechange')) {
+        f = eval(mode + '_onpagechange');
+        f();
+    }
+}
+
 function loadpager() {
+    //Create and populate the pager, to page through multiple pages of the
+    //document (called by loadperspectivemenu())
     if (!slices[perspective]) {
         alert("Error: No slices available for perspective " + perspective + ". If you are the administrator, make sure to define this perspective in the slices in the configuration");
         return false;
@@ -556,11 +624,14 @@ function loadpager() {
         if (slices[perspective].length > page) {
             end = slices[perspective][page];
         }
-        loadcontent(perspective, null, start, end);
+        loadcontent(perspective, null, start, end, onpagechange);
     });
 }
 
+
+
 $(document).ajaxSend(function(event, xhr, settings) {
+    //Generic AJAX send function, with
     //CSRF token support for jquery AJAX request to Django
     function getCookie(name) {
         var cookieValue = null;
@@ -600,6 +671,7 @@ $(document).ajaxSend(function(event, xhr, settings) {
 
 
 $.fn.sortOptions = function(){
+    //Generic alphabetic sort function for option elements in select
     var sel = $(this).val();
     $(this).each(function(){
         var op = $(this).children("option");
@@ -612,6 +684,7 @@ $.fn.sortOptions = function(){
 };
 
 function bySortedValue(obj, callback, context) {
+    //Generic sort by value function
     var tuples = [];
 
     for (var key in obj) tuples.push([key, obj[key]]);
@@ -636,24 +709,73 @@ function index_click() {
     $('#wait').show();
 }
 
+function submitfilemanager(filemanmode) {
+    //Submit a file management operation (sets a mode and submits the HTML form)
+    $('#filemanmode').val(filemanmode);
+    $('#filemanform').submit();
+}
+
 function auto_grow(element) {
+    //Generic auto-grow function for elements
     element.style.height = "5px";
     element.style.height = (element.scrollHeight)+"px";
 }
 
+
+function sort_targets(targets) {
+    //Sort a list of target IDs (words only) so that they are in proper order of appearance
+    var sameparent = false;
+    if ((targets.length > 0) && (structure[targets[0]]) && (structure[targets[0]].parent) && (structure[structure[targets[0]].parent].structure)) {
+        sameparent = structure[targets[0]].parent;
+        for (var i = 1; i < targets.length; i++) {
+            if (structure[targets[0]].parent != sameparent) {
+                sameparent = false;
+                break;
+            }
+        }
+    }
+    var sortedtargets = [];
+    if (sameparent) {
+        //sort targets by looking at the word order for the parent element
+        for (var j = 0; j < structure[sameparent].structure.length; j++) {
+            if (targets.indexOf(structure[sameparent].structure[j]) > -1) {
+                sortedtargets.push(structure[sameparent].structure[j]);
+            }
+        }
+    } else {
+        //fallback: sort targets by simply looking at the order they are rendered in  the interface
+        $('.w').each(function(){
+            if (targets.indexOf(this.id) > -1) {
+                sortedtargets.push(this.id);
+            }
+        });
+    }
+    if (sortedtargets.length != targets.length) {
+        throw "Error, unable to sort targets, expected " + targets.length + ", got " + sortedtargets.length;
+    }
+    return sortedtargets;
+}
+
 function escape_fql_value(v) {
-    return v.replace('"','\\"');
+    //Escape values in FQL
+    return v.replace(/"/g,'\\"').replace(/\n/g,"\\n");
 }
 
 $(function() {
+    //on page load
+    //
+    //clear any wait screens (needed when user pressed back in browser)
+    $('#wait').hide();
     if (typeof(mode) != "undefined") {
+        folia_parse(foliaspec, []);
+
         $('nav>ul>li').mouseenter(function(){
             $('>ul',this).css('left', mouseX-30);
         });
 
-        //loadtext(initialannotationlist);
-        //loadannotations(initialannotationlist);
+        //Load the declarations, set definitions
         loaddeclarations(initialdeclarationlist);
+        //Register handlers for all elements
         registerhandlers();
         if ((namespace != "testflat")  || (docid == "manual")) {
             //get the data first of all (will take a while anyway)
@@ -662,8 +784,10 @@ $(function() {
                 perspective_start = slices[perspective][0];
                 perspective_end = slices[perspective][1];
             }
+            //Request content to be loaded (will be a call to server) and eventually calls update()
             loadcontent(perspective, perspective_ids, perspective_start, perspective_end);
         }
+        //Delegate to mode-specific callback
         if (function_exists(mode + '_oninit')) {
             f = eval(mode + '_oninit');
             f();
