@@ -93,6 +93,8 @@ DEFAULTMODE = 'editor'
 # will be selected by default:
 DEFAULTCONFIGURATION = 'full'
 
+# Allow public anonymous uploads without any authentication?
+ALLOWPUBLICUPLOAD = False
 
 #These are the configurations, add new ones by copying the 'full' configuration and adapting it to your needs.
 CONFIGURATIONS = {
@@ -113,6 +115,9 @@ CONFIGURATIONS = {
     # Allow users to upload FoLiA documents?
     'allowupload': True, #boolean
 
+    #Automatically create namespaces for all the groups a user is in and has write permission for,
+    'creategroupnamespaces': True, #boolean
+
     # The default annotation focus upon loading a document
     # The annotation type that has is set as annotation focus will be
     # visualised. Set to a valid FoLiA tag name (see the FoLiA documentation at
@@ -129,6 +134,10 @@ CONFIGURATIONS = {
     #'annotationfocusset': 'https://raw.githubusercontent.com/proycon/folia/master/setdefinitions/namedentities.foliaset.xml',
 
 
+    # Automatically enable the select span button for the annotation focus when opening the editor dialog
+    'autoselectspan': False,
+
+
     # List of FoLiA annotation types (xml tags) that are allowed as annotation focus, set to True to enable all.
     # Users may switch annotation focus through the menu
     # Here and everywhere else, the annotation type equals the FoLiA XML tag
@@ -201,7 +210,7 @@ CONFIGURATIONS = {
     #Allow confidence values to be set/edited?
     'allowconfidence': True,
 
-    # FoLiA set to use fo corrections
+    # FoLiA set to use for corrections
     #'initialcorrectionset': 'http://raw.github.com/proycon/folia/master/setdefinitions/spellingcorrection.foliaset.xml',
 
     # List of 2-tuples (tag,set) that specify what annotation types and with
@@ -214,6 +223,23 @@ CONFIGURATIONS = {
     #    ('entity', 'https://raw.githubusercontent.com/proycon/folia/master/setdefinitions/namedentities.foliaset.xml')
     #],
 
+    # List of 2-tuples (tag,set) that specify what annotation types and with
+    # what are required sets to be already present for each document that is
+    # opened. This is more or less the opposite of autodeclare
+
+    #'requiredeclaration': [
+    #    ('correction', 'http://raw.github.com/proycon/folia/master/setdefinitions/spellingcorrection.foliaset.xml')
+    #    ('entity', 'https://raw.githubusercontent.com/proycon/folia/master/setdefinitions/namedentities.foliaset.xml')
+    #],
+
+    #List of metadata keys (in  FoLiA's native metadata) to show in the
+    # document index.
+    #'metadataindex': ['status','language','title'],
+
+    #Dictionary of metadata keys to lists of possible values, constrains the values in the metadata editor rather than offering a free-fill field. Example:
+    #'metadataconstraints': {'language': ['fr','en','es'], 'status':['completed','inprogress']},
+
+    #'searches': [{'query': 'SELECT entity WHERE annotatortype = "manual" FOR w RETURN target', 'label': "Highlight manually annotated entities"}]
 },
 }
 
@@ -437,9 +463,22 @@ SESSION_SERIALIZER = 'django.contrib.sessions.serializers.JSONSerializer'
 #Remove this when done configuring:
 raise Exception("settings.py hasn't been configured yet!!")
 
+
 # Now you can start FLAT as follows:
 
 # $ export PYTHONPATH=/your/settings/path/
-# $ django-admin runserver --settings settings
+# $ export DJANGO_SETTINGS_MODULE=settings
+# $ django-admin runserver
 
-# Don't forget to start the document server too
+# But before the first time you run you will want to run the migrations and populate the
+# database:
+
+# $ export PYTHONPATH=/your/settings/path/
+# $ export DJANGO_SETTINGS_MODULE=settings
+# $ django-admin makemigrations
+# $ django-admin migrate --run-syncdb
+# $ django-admin createsuperuser
+
+# In any case, don't forget to start the document server too:
+
+# $ foliadocserve -d /path/to/document/root -p 8080 --git
